@@ -14,6 +14,7 @@
 #include <QTextCursor>
 #include <QPlainTextEdit>
 #include <QTextBlock>
+#include <QDebug>
 #include "blockdata.h"
 
 LineNumberWidget::LineNumberWidget(LatexEditor* editor, QWidget* parent)
@@ -28,6 +29,7 @@ setPalette( p );
 start=-1;
 end=-1;
 connect( m_editor->verticalScrollBar(), SIGNAL( valueChanged( int ) ), this, SLOT( update() ) );
+connect( m_editor->verticalScrollBar(), SIGNAL( actionTriggered( int ) ), this, SLOT( update() ) );
 connect( m_editor, SIGNAL( textChanged() ), this, SLOT( update() ) );
 connect(m_editor, SIGNAL(updatelineWidget()), this, SLOT(update()));
 connect( m_editor, SIGNAL( setBlockRange(int,int) ), this, SLOT( setRange(int,int) ) );
