@@ -29,11 +29,13 @@ public slots:
     virtual void doReplaceAll();
     void SetEditor(LatexEditor *ed);
     void doHide();
-    
+private slots:
+    void expand(bool e);    
 protected:
     LatexEditor *editor;
 signals:
 void requestHide();
+void requestExtension();
 };
 
 #endif 
